-- Predefined question types, unmodifiable!
CREATE TABLE SC_QUESTIONTYPE (
  ID INTEGER NOT NULL,
  NAME VARCHAR2(50) NOT NULL
);

ALTER TABLE SC_QUESTIONTYPE ADD CONSTRAINT SC_QUESTIONTYPE_PK PRIMARY KEY (ID);

ALTER TABLE SC_QUESTIONTYPE ADD CONSTRAINT SC_QUESTIONTYPE_U1 UNIQUE (NAME);

INSERT INTO SC_QUESTIONTYPE (ID, NAME) VALUES (1, 'Text');

INSERT INTO SC_QUESTIONTYPE (ID, NAME) VALUES (2, 'Multiple choices, single selection');

INSERT INTO SC_QUESTIONTYPE (ID, NAME) VALUES (3, 'Multiple choices, multiple selections');

-- User defined predefined questions
CREATE TABLE SC_QUESTION (
  ID INTEGER NOT NULL,
  SC_QUESTIONTYPE_ID INTEGER NOT NULL,
  NAME VARCHAR2(100) NOT NULL,
  QUESTION VARCHAR2(3072) NOT NULL,
  QUESTION_HEADER VARCHAR2(3072),
  QUESTION_FOOTER VARCHAR2(3072)
);

ALTER TABLE SC_QUESTION ADD CONSTRAINT SC_QUESTION_PK PRIMARY KEY (ID);

ALTER TABLE SC_QUESTION ADD CONSTRAINT SC_QUESTION_U1 UNIQUE (SC_QUESTIONTYPE_ID, NAME);

ALTER TABLE SC_QUESTION ADD CONSTRAINT SC_QUESTION_QT_FK FOREIGN KEY (SC_QUESTIONTYPE_ID) REFERENCES SC_QUESTIONTYPE(ID);

CREATE SEQUENCE SC_QUESTION_SEQ START WITH 1;

-- Possible answers to questions
CREATE TABLE SC_QUESTIONANS(
  ID INTEGER NOT NULL,
  SC_QUESTION_ID INTEGER NOT NULL,
  SORTORDER INTEGER NOT NULL,
  ANSWER VARCHAR2(1024) NOT NULL
);

ALTER TABLE SC_QUESTIONANS ADD CONSTRAINT SC_QUESTIONANS_PK PRIMARY KEY (ID);

ALTER TABLE SC_QUESTIONANS ADD CONSTRAINT FK_SC_QUESTIONANS_Q FOREIGN KEY (SC_QUESTION_ID) REFERENCES SC_QUESTION(ID);

ALTER TABLE SC_QUESTIONANS ADD CONSTRAINT SC_QUESTIONANS_U1 UNIQUE (SC_QUESTION_ID, ANSWER);

ALTER TABLE SC_QUESTIONANS ADD CONSTRAINT SC_QUESTIONANS_U2 UNIQUE (SC_QUESTION_ID, SORTORDER);

CREATE SEQUENCE SC_QUESTIONANS_SEQ START WITH 1;

-- Application form
CREATE TABLE SC_APPFORM(
  ID INTEGER NOT NULL,
  NAME VARCHAR2(255) NOT NULL,
  HEADER VARCHAR2(3072),
  FOOTER VARCHAR2(3072)
);

ALTER TABLE SC_APPFORM ADD CONSTRAINT SC_APPFORM_PK PRIMARY KEY (ID);

ALTER TABLE SC_APPFORM ADD CONSTRAINT SC_APPFORM_U1 UNIQUE (NAME);

CREATE SEQUENCE SC_APPFORM_SEQ START WITH 1;

-- Application form sections
CREATE TABLE SC_APPFORMSEC (
  ID INTEGER NOT NULL,
  SC_APPFORM_ID INTEGER NOT NULL,
  NUM INTEGER NOT NULL,
  NAME VARCHAR2(1024) NOT NULL
);

ALTER TABLE SC_APPFORMSEC ADD CONSTRAINT SC_APPFORMSEC_PK PRIMARY KEY (ID);

ALTER TABLE SC_APPFORMSEC ADD CONSTRAINT SC_APPFORMSEC_FRM_FK FOREIGN KEY (SC_APPFORM_ID) REFERENCES SC_APPFORM(ID);

ALTER TABLE SC_APPFORMSEC ADD CONSTRAINT SC_APPFORMSEC_FRM_U1 UNIQUE (SC_APPFORM_ID, NUM);

ALTER TABLE SC_APPFORMSEC ADD CONSTRAINT SC_APPFORMSEC_FRM_U2 UNIQUE (SC_APPFORM_ID, NAME);

CREATE SEQUENCE SC_APPFORMSEC_SEQ START WITH 1;

-- Application form questions
CREATE TABLE SC_APPFORMQ (
  ID INTEGER NOT NULL,
  SC_APPFORMSEC_ID INTEGER NOT NULL,
  SC_QUESTION_ID INTEGER NOT NULL,
  NUM INTEGER NOT NULL
);

ALTER TABLE SC_APPFORMQ ADD CONSTRAINT SC_APPFORMQ_PK PRIMARY KEY(ID);

ALTER TABLE SC_APPFORMQ ADD CONSTRAINT SC_APPFORMQ_S_FK FOREIGN KEY (SC_APPFORMSEC_ID) REFERENCES SC_APPFORMSEC(ID);

ALTER TABLE SC_APPFORMQ ADD CONSTRAINT SC_APPFORM_Q_FK FOREIGN KEY (SC_QUESTION_ID) REFERENCES SC_QUESTION(ID);

ALTER TABLE SC_APPFORMQ ADD CONSTRAINT SC_APPFORMQ_U1 UNIQUE (SC_APPFORMSEC_ID, SC_QUESTION_ID);

ALTER TABLE SC_APPFORMQ ADD CONSTRAINT SC_APPFORMQ_U2 UNIQUE (SC_APPFORMSEC_ID, NUM);

CREATE SEQUENCE SC_APPFORMQ_SEQ START WITH 1;

-- FIX za teave v predhodnjih verzijah
ALTER TABLE SC_EVENTRES DROP COLUMN DATE_START;

ALTER TABLE SC_EVENTRES DROP COLUMN DATE_END;

CREATE OR REPLACE VIEW V_SC_EVENTRES AS
SELECT ER.*, E.NAME AS EVENT_NAME, ES.SC_RESTYPE_ID, R.RESTYPECODE, R.NAME AS CUSTOM_NAME, R.PLOVILA_ID, R.KUPCI_ID, P.IME AS PLOVILA_IME,
TRIM((CASE WHEN NVL(K.NTITLE, '') = '' THEN '' ELSE K.NTITLE || '.' END) || ' ' || NVL(K.IME, '') || ' ' || NVL(K.PRIIMEK, '')) AS KUPCI_IME
FROM SC_EVENTRES ER
JOIN SC_EVENT E ON E.ID = ER.SC_EVENT_ID
JOIN SC_EVRES ES ON ES.ID = ER.SC_EVRES_ID
JOIN SC_RESOURCE R ON R.ID = ER.SC_RESOURCE_ID
LEFT OUTER JOIN PLOVILA P ON P.ID = R.PLOVILA_ID
LEFT OUTER JOIN KUPCI K ON K.ID = R.KUPCI_ID;

-- Additional question attributes
ALTER TABLE SC_QUESTION ADD ISFREETEXT VARCHAR2(1);

UPDATE SC_QUESTION SET ISFREETEXT = 'F' WHERE ISFREETEXT IS NULL;

ALTER TABLE SC_QUESTION MODIFY (ISFREETEXT NOT NULL);

ALTER TABLE SC_QUESTION ADD LINECOUNT INTEGER;

UPDATE SC_QUESTION SET LINECOUNT = 1 WHERE LINECOUNT IS NULL;

ALTER TABLE SC_QUESTION MODIFY (LINECOUNT NOT NULL);

insert into verzije_baza (id, dt_vpis, verzija, ver_nr, opis) 
values 
(486, SYSDATE, '5.5', 406, 'Sailing Training Centre');